%define   anolis_release    1
%define   version_alsa_lib  1.2.8
%define   version_alsa_ucm  1.2.8
%define   version_alsa_tplg 1.2.5.1

Summary:  The Advanced Linux Sound Architecture (ALSA) library
Name:     alsa-lib
Version:  %{version_alsa_lib}
Release:  %{anolis_release}%{?dist}
License:  LGPLv2+
URL:      https://www.alsa-project.org

Source0:  https://www.alsa-project.org/files/pub/lib/%{name}-%{version}.tar.bz2
Source1:  https://www.alsa-project.org/files/pub/lib/alsa-ucm-conf-%{version_alsa_ucm}.tar.bz2
Source2:  https://www.alsa-project.org/files/pub/lib/alsa-topology-conf-%{version_alsa_tplg}.tar.bz2
Source3:  asound.conf
Source4:  modprobe-dist-alsa.conf
Source5:  modprobe-dist-oss.conf

Patch1:   0001-alsa-lib-1.0.14-glibc-open.patch

BuildRequires:  doxygen
BuildRequires:  autoconf automake libtool
BuildRequires: make

%description
The Advanced Linux Sound Architecture (ALSA) provides audio and MIDI
functionality to the Linux operating system.

This package includes the ALSA runtime libraries to simplify application
programming and provide higher level functionality as well as support for
the older OSS API, providing binary compatibility for most OSS programs.

%package  devel
Summary:  Development files from the ALSA library
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig

%description devel
The Advanced Linux Sound Architecture (ALSA) provides audio and MIDI
functionality to the Linux operating system.

This package includes the ALSA development libraries for developing
against the ALSA libraries and interfaces.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package  -n alsa-ucm
Summary:   ALSA Use Case Manager configuration
BuildArch: noarch
License:   BSD
Requires:  %{name} >= %{version_alsa_lib}

%description -n alsa-ucm
The Advanced Linux Sound Architecture (ALSA) Use Case Manager configuration
contains alsa-lib configuration of Audio input/output names and routing

%package  -n alsa-topology
Summary:   ALSA Topology configuration
BuildArch: noarch
License:   BSD
Requires:  %{name} >= %{version_alsa_lib}

%description -n alsa-topology
The Advanced Linux Sound Architecture (ALSA) topology configuration
contains alsa-lib configuration of SoC topology

%prep
%autosetup -p1

%build
%define _lto_cflags -flto -ffat-lto-objects -flto-partition=none

autoreconf -vif
%configure --disable-aload --with-plugindir=%{_libdir}/alsa-lib --disable-alisp

%make_build
%make_build doc

%install
%global sysmodprobedir %{_prefix}/lib/modprobe.d

%make_install

# Install global configuration files
mkdir -p -m 755 %{buildroot}/etc
install -p -m 644 %{SOURCE3} %{buildroot}/etc

# Install the modprobe files for ALSA
mkdir -p -m 755 %{buildroot}%{sysmodprobedir}
install -p -m 644 %{SOURCE4} %{buildroot}%{sysmodprobedir}/dist-alsa.conf
install -p -m 644 %{SOURCE5} .

# Create UCM directories
mkdir -p %{buildroot}/%{_datadir}/alsa/ucm
mkdir -p %{buildroot}/%{_datadir}/alsa/ucm2

# Unpack UCMs
tar xvjf %{SOURCE1} -C %{buildroot}/%{_datadir}/alsa --wildcards --strip-components=1 "*/ucm" "*/ucm2"

# Create topology directory
mkdir -p %{buildroot}/%{_datadir}/alsa/topology

# Unpack topologies
tar xvjf %{SOURCE2} -C %{buildroot}/%{_datadir}/alsa --wildcards --strip-components=1 "*/topology"

# Remove /usr/include/asoundlib.h
rm %{buildroot}/%{_includedir}/asoundlib.h

%generate_compatibility_deps

%files
%{!?_licensedir:%global license %%doc}
%license COPYING
%dir %{abidir}
%doc doc/asoundrc.txt modprobe-dist-oss.conf
%config %{_sysconfdir}/asound.conf
%{_libdir}/libasound.so.*
%{_libdir}/libatopology.so.*
%{abidir}/libasound.dump
%{abidir}/libatopology.dump
%{_bindir}/aserver
%{abidir}/aserver-option.list
%{_datadir}/alsa/
%exclude %{_datadir}/alsa/ucm
%exclude %{_datadir}/alsa/ucm2
%exclude %{_datadir}/alsa/topology
%{sysmodprobedir}/dist-*

%files devel
%doc doc/doxygen/
%{_includedir}/alsa/
%{_includedir}/sys/asoundlib.h
%{_libdir}/libasound.so
%{_libdir}/libatopology.so
%{_libdir}/pkgconfig/alsa.pc
%{_libdir}/pkgconfig/alsa-topology.pc
%{_datadir}/aclocal/alsa.m4

%files doc
%doc TODO

%files -n alsa-ucm
# BSD
%{_datadir}/alsa/ucm
%{_datadir}/alsa/ucm2

%files -n alsa-topology
# BSD
%{_datadir}/alsa/topology

%changelog
* Sun Oct 30 2022 Funda Wang <fundawang@yeah.net> - 1.2.8-1
- New version 1.2.8

* Fri Oct 14 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.2.7.2-3
- optimise spec file

* Tue Oct 11 2022 happy_orange <songnannan@linux.alibaba.com> - 1.2.7.2-2
- add abi and api file.

* Fri Sep 23 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.2.7.2-1
- update to 1.2.7.2

* Mon Apr 18 2022 yuanhui <yuanhui@linux.alibaba.com> - 1.2.6.1-1
- Init alsa-lib for anolis os 23
